@@ -24,71 +24,37 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-lambda-secretsmanager`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.lambdasecretsmanager`|
 
-## Overview
-
 This AWS Solutions Construct implements the AWS Lambda function and AWS Secrets Manager secret with the least privileged permissions.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
-Typescript
+```javascript
+const { LambdaToSecretsmanagerProps,  LambdaToSecretsmanager } from '@aws-solutions-constructs/aws-lambda-secretsmanager';
 
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { LambdaToSecretsmanagerProps, LambdaToSecretsmanager } from '@aws-solutions-constructs/aws-lambda-secretsmanager';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-
-const constructProps: LambdaToSecretsmanagerProps = {
-  lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_14_X,
-    code: lambda.Code.fromAsset(`lambda`),
-    handler: 'index.handler'
-  },
+const props: LambdaToSecretsmanagerProps = {
+    lambdaFunctionProps: {
+      runtime: lambda.Runtime.NODEJS_14_X,
+      // This assumes a handler function in lib/lambda/index.js
+      code: lambda.Code.fromAsset(`${__dirname}/lambda`),
+      handler: 'index.handler'
+    },
 };
 
-new LambdaToSecretsmanager(this, 'test-lambda-secretsmanager-stack', constructProps);
+new LambdaToSecretsmanager(this, 'test-lambda-secretsmanager-stack', props);
+
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_lambda_secretsmanager import LambdaToSecretsmanagerProps, LambdaToSecretsmanager
-from aws_cdk import (
-    aws_lambda as _lambda,
-    Stack
-)
-from constructs import Construct
-
-
-LambdaToSecretsmanager(
-    self, 'test-lambda-secretsmanager-stack',
-    lambda_function_props=_lambda.FunctionProps(
-        code=_lambda.Code.from_asset('lambda'),
-        runtime=_lambda.Runtime.PYTHON_3_9,
-        handler='index.handler'
-    )
-)
+```text
+new LambdaToSecretsmanager(scope: Construct, id: string, props: LambdaToSecretsmanagerProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.lambdasecretsmanager.*;
-
-new LambdaToSecretsmanager(this, "test-lambda-secretsmanager-stack", new LambdaToSecretsmanagerProps.Builder()
-        .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_14_X)
-                .code(Code.fromAsset("lambda"))
-                .handler("index.handler")
-                .build())
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`LambdaToSecretsmanagerProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -98,8 +64,8 @@ new LambdaToSecretsmanager(this, "test-lambda-secretsmanager-stack", new LambdaT
 |lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |secretProps?|[`secretsmanager.SecretProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-secretsmanager.SecretProps.html)|Optional user provided props to override the default props for Secrets Manager|
 |existingSecretObj?|[`secretsmanager.Secret`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-secretsmanager.Secret.html)|Existing instance of Secrets Manager Secret object, If this is set then the secretProps is ignored|
-|grantWriteAccess?|`string`|Optional Access granted to the Lambda function for the secret. 'Read' or 'ReadWrite". Default is "Read"
-|secretEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the ARN of the secret. Default: SECRET_ARN. |
+|grantWriteAccess?|`boolean`|Optional write access to the Secret for the Lambda function (Read-Only by default)
+|secretEnvironmentVariableName?|`string`|Optional Name for the Secrets Manager secret environment variable set for the Lambda function.|
 |existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for AWS Secrets Manager. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
 |vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
 |deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
@@ -129,6 +95,7 @@ Out of the box implementation of the Construct without any override will set the
 ### Amazon SecretsManager Secret
 
 * Enable read-only access for the associated AWS Lambda Function
+* Enable server-side encryption using a default KMS key for the account and region
 * Creates a new Secret
 
   * (default) random name
@@ -142,7 +109,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -154,18 +121,16 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_ec2
 import aws_cdk.aws_lambda
 import aws_cdk.aws_secretsmanager
-import aws_cdk.core
+import constructs
 
 
 class LambdaToSecretsmanager(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-lambda-secretsmanager.LambdaToSecretsmanager",
 ):
@@ -175,7 +140,7 @@ class LambdaToSecretsmanager(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         deploy_vpc: typing.Optional[builtins.bool] = None,
@@ -183,10 +148,10 @@ class LambdaToSecretsmanager(
         existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         grant_write_access: typing.Optional[builtins.str] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         secret_environment_variable_name: typing.Optional[builtins.str] = None,
-        secret_props: typing.Optional[typing.Union[aws_cdk.aws_secretsmanager.SecretProps, typing.Dict[str, typing.Any]]] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        secret_props: typing.Optional[aws_cdk.aws_secretsmanager.SecretProps] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -197,32 +162,13 @@ class LambdaToSecretsmanager(
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param grant_write_access: Optional secret permissions to grant to the Lambda function. One of the following may be specified: "Read" or "ReadWrite". Default: - Read only acess is given to the Lambda function if no value is specified.
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
-        :param secret_environment_variable_name: Optional Name for the Lambda function environment variable set to the ARN of the secret. Default: - SECRET_ARN
+        :param secret_environment_variable_name: Optional Name for the Secret environment variable set for the Lambda function. Default: - SECRET_NAME
         :param secret_props: Optional user-provided props to override the default props for the Secret. Default: - Default props are used
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :access: public
         :summary: Constructs a new instance of the LambdaToSecretsmanager class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                grant_write_access: typing.Optional[builtins.str] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                secret_environment_variable_name: typing.Optional[builtins.str] = None,
-                secret_props: typing.Optional[typing.Union[aws_cdk.aws_secretsmanager.SecretProps, typing.Dict[str, typing.Any]]] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToSecretsmanagerProps(
             deploy_vpc=deploy_vpc,
             existing_lambda_obj=existing_lambda_obj,
@@ -237,17 +183,17 @@ class LambdaToSecretsmanager(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="secret")
     def secret(self) -> aws_cdk.aws_secretsmanager.Secret:
         return typing.cast(aws_cdk.aws_secretsmanager.Secret, jsii.get(self, "secret"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
@@ -277,10 +223,10 @@ class LambdaToSecretsmanagerProps:
         existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         grant_write_access: typing.Optional[builtins.str] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         secret_environment_variable_name: typing.Optional[builtins.str] = None,
-        secret_props: typing.Optional[typing.Union[aws_cdk.aws_secretsmanager.SecretProps, typing.Dict[str, typing.Any]]] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        secret_props: typing.Optional[aws_cdk.aws_secretsmanager.SecretProps] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -289,7 +235,7 @@ class LambdaToSecretsmanagerProps:
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param grant_write_access: Optional secret permissions to grant to the Lambda function. One of the following may be specified: "Read" or "ReadWrite". Default: - Read only acess is given to the Lambda function if no value is specified.
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
-        :param secret_environment_variable_name: Optional Name for the Lambda function environment variable set to the ARN of the secret. Default: - SECRET_ARN
+        :param secret_environment_variable_name: Optional Name for the Secret environment variable set for the Lambda function. Default: - SECRET_NAME
         :param secret_props: Optional user-provided props to override the default props for the Secret. Default: - Default props are used
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
@@ -301,30 +247,6 @@ class LambdaToSecretsmanagerProps:
             secret_props = aws_cdk.aws_secretsmanager.SecretProps(**secret_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
-        if __debug__:
-            def stub(
-                *,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                grant_write_access: typing.Optional[builtins.str] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                secret_environment_variable_name: typing.Optional[builtins.str] = None,
-                secret_props: typing.Optional[typing.Union[aws_cdk.aws_secretsmanager.SecretProps, typing.Dict[str, typing.Any]]] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
-            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
-            check_type(argname="argument existing_secret_obj", value=existing_secret_obj, expected_type=type_hints["existing_secret_obj"])
-            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
-            check_type(argname="argument grant_write_access", value=grant_write_access, expected_type=type_hints["grant_write_access"])
-            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
-            check_type(argname="argument secret_environment_variable_name", value=secret_environment_variable_name, expected_type=type_hints["secret_environment_variable_name"])
-            check_type(argname="argument secret_props", value=secret_props, expected_type=type_hints["secret_props"])
-            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if deploy_vpc is not None:
             self._values["deploy_vpc"] = deploy_vpc
@@ -402,9 +324,9 @@ class LambdaToSecretsmanagerProps:
 
     @builtins.property
     def secret_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the Lambda function environment variable set to the ARN of the secret.
+        '''Optional Name for the Secret environment variable set for the Lambda function.
 
-        :default: - SECRET_ARN
+        :default: - SECRET_NAME
         '''
         result = self._values.get("secret_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
